searchData={"content_type":"text/markdown","items":[{"doc":"Fast and secure MIME type detection using the system's `file` command.\n\nThis library provides a safe interface to detect MIME types for files\nwithout requiring NIFs or external dependencies (other than the system's\n`file` command).","ref":"MagicMime.html","title":"MagicMime","type":"module"},{"doc":"iex> {:ok, mime_type} = MagicMime.detect(\"mix.exs\")\n    iex> String.starts_with?(mime_type, \"text/\")\n    true\n\n    iex> mime_type = MagicMime.detect!(\"mix.exs\")\n    iex> String.starts_with?(mime_type, \"text/\")\n    true\n\n    iex> results = MagicMime.detect_many([\"mix.exs\", \"README.md\"])\n    iex> Enum.all?(results, fn {_path, {:ok, mime_type}} -> String.starts_with?(mime_type, \"text/\") end)\n    true","ref":"MagicMime.html#module-examples","title":"Examples - MagicMime","type":"module"},{"doc":"This library requires the `file` command to be available on the system.\nIt's pre-installed on most Unix-like systems (Linux, macOS, etc.).\n\n**Note**: Windows is not supported.","ref":"MagicMime.html#module-requirements","title":"Requirements - MagicMime","type":"module"},{"doc":"Detects the MIME type of a file.\n\nReturns `{:ok, mime_type}` on success, or `{:error, reason}` on failure.","ref":"MagicMime.html#detect/2","title":"MagicMime.detect/2","type":"function"},{"doc":"- `:command_executor` - Custom command executor for dependency injection\n- `:file_system` - Custom file system for dependency injection","ref":"MagicMime.html#detect/2-options","title":"Options - MagicMime.detect/2","type":"function"},{"doc":"iex> {:ok, mime_type} = MagicMime.detect(\"mix.exs\")\n    iex> String.starts_with?(mime_type, \"text/\")\n    true\n\n    iex> MagicMime.detect(\"nonexistent.file\")\n    {:error, :enoent}","ref":"MagicMime.html#detect/2-examples","title":"Examples - MagicMime.detect/2","type":"function"},{"doc":"- `:file_command_not_found` - The `file` command is not available\n- `:enoent` - File does not exist\n- `:eacces` - Permission denied\n- `{:command_error, exit_code, stderr}` - Command execution failed","ref":"MagicMime.html#detect/2-error-types","title":"Error Types - MagicMime.detect/2","type":"function"},{"doc":"Detects the MIME type of a file, raising an exception on failure.\n\nReturns the MIME type as a string on success, or raises `MagicMime.Error`\non failure.","ref":"MagicMime.html#detect!/2","title":"MagicMime.detect!/2","type":"function"},{"doc":"- `:command_executor` - Custom command executor for dependency injection\n- `:file_system` - Custom file system for dependency injection","ref":"MagicMime.html#detect!/2-options","title":"Options - MagicMime.detect!/2","type":"function"},{"doc":"iex> mime_type = MagicMime.detect!(\"mix.exs\")\n    iex> String.starts_with?(mime_type, \"text/\")\n    true\n\n    iex> MagicMime.detect!(\"nonexistent.file\")\n    ** (MagicMime.Error) File does not exist: nonexistent.file","ref":"MagicMime.html#detect!/2-examples","title":"Examples - MagicMime.detect!/2","type":"function"},{"doc":"Detects MIME types for multiple files in parallel.\n\nReturns a list of tuples containing the file path and the result\n(`{:ok, mime_type}` or `{:error, reason}`).","ref":"MagicMime.html#detect_many/2","title":"MagicMime.detect_many/2","type":"function"},{"doc":"- `:concurrency` - Number of concurrent tasks (default: `System.schedulers_online()`)\n- `:command_executor` - Custom command executor for dependency injection\n- `:file_system` - Custom file system for dependency injection","ref":"MagicMime.html#detect_many/2-options","title":"Options - MagicMime.detect_many/2","type":"function"},{"doc":"iex> results = MagicMime.detect_many([\"mix.exs\", \"README.md\"])\n    iex> Enum.all?(results, fn {_path, {:ok, mime_type}} -> String.starts_with?(mime_type, \"text/\") end)\n    true\n\n    iex> results = MagicMime.detect_many([\"mix.exs\", \"README.md\"], concurrency: 2)\n    iex> Enum.all?(results, fn {_path, {:ok, mime_type}} -> String.starts_with?(mime_type, \"text/\") end)\n    true","ref":"MagicMime.html#detect_many/2-examples","title":"Examples - MagicMime.detect_many/2","type":"function"},{"doc":"","ref":"MagicMime.html#t:error_reason/0","title":"MagicMime.error_reason/0","type":"type"},{"doc":"Checks if MIME type detection is supported on this system.\n\nReturns `true` if the `file` command is available, `false` otherwise.","ref":"MagicMime.html#mime_supported?/1","title":"MagicMime.mime_supported?/1","type":"function"},{"doc":"- `:command_executor` - Custom command executor for dependency injection","ref":"MagicMime.html#mime_supported?/1-options","title":"Options - MagicMime.mime_supported?/1","type":"function"},{"doc":"iex> MagicMime.mime_supported?()\n    true","ref":"MagicMime.html#mime_supported?/1-examples","title":"Examples - MagicMime.mime_supported?/1","type":"function"},{"doc":"","ref":"MagicMime.html#t:mime_type/0","title":"MagicMime.mime_type/0","type":"type"},{"doc":"","ref":"MagicMime.html#t:path/0","title":"MagicMime.path/0","type":"type"},{"doc":"Returns the version of the `file` command.\n\nReturns `{:ok, version}` on success, or `{:error, reason}` on failure.","ref":"MagicMime.html#version/1","title":"MagicMime.version/1","type":"function"},{"doc":"- `:command_executor` - Custom command executor for dependency injection","ref":"MagicMime.html#version/1-options","title":"Options - MagicMime.version/1","type":"function"},{"doc":"iex> {:ok, version} = MagicMime.version()\n    iex> is_binary(version)\n    true\n\n    iex> {:ok, version} = MagicMime.version()\n    iex> is_binary(version)\n    true","ref":"MagicMime.html#version/1-examples","title":"Examples - MagicMime.version/1","type":"function"},{"doc":"Internal module for executing the `file` command.","ref":"MagicMime.CLI.html","title":"MagicMime.CLI","type":"module"},{"doc":"Executes the `file` command to detect MIME type for a given file path.","ref":"MagicMime.CLI.html#detect_mime_type/2","title":"MagicMime.CLI.detect_mime_type/2","type":"function"},{"doc":"Checks if the `file` command is available on the system.","ref":"MagicMime.CLI.html#file_command_available?/1","title":"MagicMime.CLI.file_command_available?/1","type":"function"},{"doc":"Gets the version of the `file` command.","ref":"MagicMime.CLI.html#get_version/1","title":"MagicMime.CLI.get_version/1","type":"function"},{"doc":"Validates if a file path exists and is accessible.","ref":"MagicMime.CLI.html#validate_file_path/2","title":"MagicMime.CLI.validate_file_path/2","type":"function"},{"doc":"Protocol for executing system commands. Allows dependency injection for testing.","ref":"MagicMime.CommandExecutor.html","title":"MagicMime.CommandExecutor","type":"module"},{"doc":"Default implementation using Elixir's System module.","ref":"MagicMime.CommandExecutor.System.html","title":"MagicMime.CommandExecutor.System","type":"module"},{"doc":"","ref":"MagicMime.CommandExecutor.System.html#cmd/3","title":"MagicMime.CommandExecutor.System.cmd/3","type":"function"},{"doc":"","ref":"MagicMime.CommandExecutor.System.html#find_executable/1","title":"MagicMime.CommandExecutor.System.find_executable/1","type":"function"},{"doc":"Protocol for file system operations. Allows dependency injection for testing.","ref":"MagicMime.FileSystem.html","title":"MagicMime.FileSystem","type":"module"},{"doc":"Default implementation using Elixir's File module.","ref":"MagicMime.FileSystem.File.html","title":"MagicMime.FileSystem.File","type":"module"},{"doc":"","ref":"MagicMime.FileSystem.File.html#exists?/1","title":"MagicMime.FileSystem.File.exists?/1","type":"function"},{"doc":"","ref":"MagicMime.FileSystem.File.html#stat/1","title":"MagicMime.FileSystem.File.stat/1","type":"function"},{"doc":"Custom exception for MagicMime operations.","ref":"MagicMime.Error.html","title":"MagicMime.Error","type":"exception"},{"doc":"# MagicMime\n\n[![CI](https://github.com/urth-inc/magic_mime/workflows/CI/badge.svg)](https://github.com/urth-inc/magic_mime/actions)\n[![Coverage Status](https://coveralls.io/repos/github/urth-inc/magic_mime/badge.svg?branch=main)](https://coveralls.io/github/urth-inc/magic_mime?branch=main)\n[![Hex.pm](https://img.shields.io/hexpm/v/magic_mime.svg)](https://hex.pm/packages/magic_mime)\n[![Documentation](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/magic_mime)\n[![License](https://img.shields.io/badge/license-MIT-green.svg)](LICENSE)\n\nElixir wrapper for MIME type detection using the system's file command.","ref":"readme.html","title":"MagicMime","type":"extras"},{"doc":"- Wrapper around the system file command\n- Binary detection (not guess from file extension)\n- Parallel processing support for multiple files","ref":"readme.html#features","title":"Features - MagicMime","type":"extras"},{"doc":"- System file command must be available\n\nNote: Windows is not supported.","ref":"readme.html#requirements","title":"Requirements - MagicMime","type":"extras"},{"doc":"Add magic_mime to your list of dependencies in mix.exs:\n\n```elixir\ndef deps do\n  [\n    {:magic_mime, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - MagicMime","type":"extras"},{"doc":"","ref":"readme.html#usage","title":"Usage - MagicMime","type":"extras"},{"doc":"```elixir\n# Detect MIME type for a single file\n{:ok, mime_type} = MagicMime.detect(\"path/to/file.png\")\n# => {:ok, \"image/png\"}\n\n# Exception-raising version\nmime_type = MagicMime.detect!(\"path/to/file.png\")\n# => \"image/png\"\n```","ref":"readme.html#basic-detection","title":"Basic Detection - MagicMime","type":"extras"},{"doc":"```elixir\n# Process multiple files in parallel\npaths = [\"image.png\", \"document.pdf\", \"data.json\"]\nresults = MagicMime.detect_many(paths)\n# => [\n#      {\"image.png\", {:ok, \"image/png\"}},\n#      {\"document.pdf\", {:ok, \"application/pdf\"}},\n#      {\"data.json\", {:ok, \"application/json\"}}\n#    ]\n\n# Specify concurrency level\nresults = MagicMime.detect_many(paths, concurrency: 4)\n```","ref":"readme.html#parallel-processing","title":"Parallel Processing - MagicMime","type":"extras"},{"doc":"```elixir\n# Check if file command is available\nMagicMime.mime_supported?()\n# => true\n\n# Get file command version information\nMagicMime.version()\n# => \"file-5.44\"\n```","ref":"readme.html#system-support-check","title":"System Support Check - MagicMime","type":"extras"},{"doc":"MagicMime provides the following error types:\n\n- `:file_command_not_found` - file command not found\n- `:enoent` - file does not exist\n- `:eacces` - permission denied\n- `{:command_error, exit_code, stderr}` - command execution error\n\n```elixir\ncase MagicMime.detect(\"nonexistent.file\") do\n  {:ok, mime_type} -> IO.puts(\"MIME Type: #{mime_type}\")\n  {:error, :enoent} -> IO.puts(\"File not found\")\n  {:error, reason} -> IO.puts(\"Error: #{inspect(reason)}\")\nend\n```","ref":"readme.html#error-handling","title":"Error Handling - MagicMime","type":"extras"},{"doc":"","ref":"readme.html#development","title":"Development - MagicMime","type":"extras"},{"doc":"```bash\n# Install dependencies\nmix deps.get\n\n# Run tests\nmix test\n\n# Generate documentation\nmix docs\n```","ref":"readme.html#setup","title":"Setup - MagicMime","type":"extras"},{"doc":"```bash\n# Format code\nmix format\n\n# Static analysis\nmix credo --strict\n\n# Type checking\nmix dialyzer\n```","ref":"readme.html#code-quality","title":"Code Quality - MagicMime","type":"extras"},{"doc":"Pull requests and issue reports are welcome.\n\n1. Fork the repository\n2. Create a feature branch (git checkout -b feature/amazing-feature)\n3. Commit your changes (git commit -am 'Add amazing feature')\n4. Push to the branch (git push origin feature/amazing-feature)\n5. Open a Pull Request","ref":"readme.html#contributing","title":"Contributing - MagicMime","type":"extras"},{"doc":"MIT License.","ref":"readme.html#license","title":"License - MagicMime","type":"extras"}],"producer":{"name":"ex_doc","version":"0.38.2"},"proglang":"elixir"}